==> Nilm-0.7.1.tar.gz: Nilm-0.7.1/tests/filters/test_rawtoprep.py <==

import unittest
import asyncio
import argparse
import os
import numpy as np
from unittest import mock

from joule import LocalNumpyPipe
from nilm.filters import rawtoprep
from nilm.filters import prep, sinefit, reconstructor


CONFIG_PATH = os.path.join(os.path.dirname(
    __file__), 'rawtoprep_files', 'meters.yml')
CAL_DIR_PATH = os.path.join(os.path.dirname(
    __file__), 'rawtoprep_files', 'meters')


class MockReconstructor(reconstructor.Reconstructor):
    async def run(self, parsed_args, inputs, outputs):
        raw = inputs['raw']
        iv = outputs['iv']
        raw_sarray = await raw.read()
        raw.consume(len(raw_sarray))
        # print(raw_sarray)
        raw_sarray["data"] += 1
        # print(raw_sarray)
        await iv.write(raw_sarray)

        
class MockSinefit(sinefit.Sinefit):
    async def run(self, parsed_args, inputs, outputs):
        iv = inputs['iv']
        zc = outputs['zero_crossings']
        iv_sarray = await iv.read()
        iv.consume(len(iv_sarray))
        iv_sarray["data"] += 1
        # print(iv_sarray)
        await zc.write(iv_sarray)

        
class MockPrep(prep.Prep):
    async def run(self, parsed_args, inputs, outputs):
        zc = inputs['zero_crossings']
        iv = inputs['iv']
        prep = outputs['prep']
        zc_sarray = await zc.read()
        iv_sarray = await iv.read()
        zc.consume(len(zc_sarray))
        iv.consume(len(iv_sarray))
        iv_sarray["data"][0] += zc_sarray["data"][0]
        # print(iv_sarray)
        await prep.write(iv_sarray)

        
class TestRawToPrep(unittest.TestCase):

    @mock.patch("nilm.filters.rawtoprep.Prep", new=MockPrep)
    @mock.patch("nilm.filters.rawtoprep.Sinefit", new=MockSinefit)
    @mock.patch("nilm.filters.rawtoprep.Reconstructor", new=MockReconstructor)
    def test_configures_pipes_to_filters(self):

        # input
        npipe_raw = LocalNumpyPipe("raw", layout="uint8_1")
        npipe_raw.write_nowait(np.array([[1.0, 0]]))
        # outputs
        npipe_zc = LocalNumpyPipe("zc", layout="uint8_1")
        npipe_iv = LocalNumpyPipe("iv", layout="uint8_1")
        npipe_prep = LocalNumpyPipe("prep", layout="uint8_1")
        args = argparse.Namespace(meter="meter1",
                                  config_file=CONFIG_PATH,
                                  calibration_directory=CAL_DIR_PATH,
                                  merge_prep=True,
                                  polar=False,
                                  frequency=60,
                                  min_voltage=10)
        my_filter = rawtoprep.RawToPrep()
        loop = asyncio.new_event_loop()
        asyncio.set_event_loop(loop)
        tasks = loop.run_until_complete(my_filter.setup(
            args,
            {"raw": npipe_raw},
            {"iv": npipe_iv,
             "zero_crossings": npipe_zc,
             "prep": npipe_prep}
        ))
        loop.run_until_complete(asyncio.gather(*tasks))
        loop.close()
        iv_result = npipe_iv.read_nowait().tolist()
        zc_result = npipe_zc.read_nowait().tolist()
        prep_result = npipe_prep.read_nowait().tolist()
        np.testing.assert_array_equal(np.array([[1.0, 1]]), iv_result)
        np.testing.assert_array_equal(np.array([[1.0, 2]]), zc_result)
        np.testing.assert_array_equal(np.array([[1.0, 3]]), prep_result)

==> Nilm-0.8.3.tar.gz: Nilm-0.8.3/tests/filters/test_rawtoprep.py <==

import unittest
import asyncio
import argparse
import os
import numpy as np
from unittest import mock

from joule import LocalPipe
from nilm.filters import rawtoprep
from nilm.filters import prep, sinefit, reconstructor


CONFIG_PATH = os.path.join(os.path.dirname(
    __file__), 'rawtoprep_files', 'meters.yml')
CAL_DIR_PATH = os.path.join(os.path.dirname(
    __file__), 'rawtoprep_files', 'meters')


class MockReconstructor(reconstructor.Reconstructor):
    async def run(self, parsed_args, inputs, outputs):
        raw = inputs['raw']
        iv = outputs['iv']
        raw_sarray = await raw.read()
        raw.consume(len(raw_sarray))
        # print(raw_sarray)
        raw_sarray["data"] += 1
        # print(raw_sarray)
        await iv.write(raw_sarray)

        
class MockSinefit(sinefit.Sinefit):
    async def run(self, parsed_args, inputs, outputs):
        iv = inputs['iv']
        zc = outputs['zero_crossings']
        iv_sarray = await iv.read()
        iv.consume(len(iv_sarray))
        iv_sarray["data"] += 1
        # print(iv_sarray)
        await zc.write(iv_sarray)

        
class MockPrep(prep.Prep):
    async def run(self, parsed_args, inputs, outputs):
        zc = inputs['zero_crossings']
        iv = inputs['iv']
        prep = outputs['prep']
        zc_sarray = await zc.read()
        iv_sarray = await iv.read()
        zc.consume(len(zc_sarray))
        iv.consume(len(iv_sarray))
        iv_sarray["data"][0] += zc_sarray["data"][0]
        # print(iv_sarray)
        await prep.write(iv_sarray)

        
class TestRawToPrep(unittest.TestCase):

    @mock.patch("nilm.filters.rawtoprep.Prep", new=MockPrep)
    @mock.patch("nilm.filters.rawtoprep.Sinefit", new=MockSinefit)
    @mock.patch("nilm.filters.rawtoprep.Reconstructor", new=MockReconstructor)
    def test_configures_pipes_to_filters(self):

        # input
        npipe_raw = LocalPipe(layout="uint8_1", name="raw")
        npipe_raw.write_nowait(np.array([[1.0, 0]]))
        # outputs
        npipe_zc = LocalPipe(layout="uint8_1", name="zc")
        npipe_iv = LocalPipe(layout="uint8_1", name="iv")
        npipe_prep = LocalPipe(layout="uint8_1", name="prep")
        args = argparse.Namespace(meter="meter1",
                                  config_file=CONFIG_PATH,
                                  calibration_directory=CAL_DIR_PATH,
                                  merge_prep=True,
                                  polar=False,
                                  frequency=60,
                                  min_voltage=10)
        my_filter = rawtoprep.RawToPrep()
        loop = asyncio.new_event_loop()
        asyncio.set_event_loop(loop)
        tasks = loop.run_until_complete(my_filter.setup(
            args,
            {"raw": npipe_raw},
            {"iv": npipe_iv,
             "zero_crossings": npipe_zc,
             "prep": npipe_prep},
            loop
        ))
        loop.run_until_complete(asyncio.gather(*tasks))
        loop.close()
        iv_result = npipe_iv.read_nowait().tolist()
        zc_result = npipe_zc.read_nowait().tolist()
        prep_result = npipe_prep.read_nowait().tolist()
        np.testing.assert_array_equal(np.array([[1.0, 1]]), iv_result)
        np.testing.assert_array_equal(np.array([[1.0, 2]]), zc_result)
        np.testing.assert_array_equal(np.array([[1.0, 3]]), prep_result)
